@@ -120,7 +120,7 @@ def load_public_key_from_path(key_path: str) -> RSAPublicKey:
                 key_file.read(),
                 backend=default_backend()
             )
-        logger.info(f"Public key file not found: {key_path}. ")
+        logger.info(f"Public key loaded successfully from {key_path}. ")
         return public_key
     except ValueError as e:
         logger.error(f"Failed to load public key, please check file format: {e}")
